@@ -1,12 +1,12 @@
 package IO::Stream::Proxy::HTTPS;
-
+use 5.010001;
 use warnings;
 use strict;
+use utf8;
 use Carp;
 
-use version; our $VERSION = qv('1.0.5');    # update POD & Changes & README
+our $VERSION = 'v2.0.0';
 
-# update DEPENDENCIES in POD & Makefile.PL & README
 use IO::Stream::const;
 use MIME::Base64;
 use Scalar::Util qw( weaken );
@@ -109,7 +109,7 @@ IO::Stream::Proxy::HTTPS - HTTPS proxy plugin for IO::Stream
 
 =head1 VERSION
 
-This document describes IO::Stream::Proxy::HTTPS version 1.0.5
+This document describes IO::Stream::Proxy::HTTPS version v2.0.0
 
 
 =head1 SYNOPSIS
@@ -185,62 +185,63 @@ IO::Stream->new() instead.
 =back
 
 
-=head1 CONFIGURATION AND ENVIRONMENT
+=head1 SUPPORT
 
-IO::Stream::Proxy::HTTPS requires no configuration files or environment variables.
+=head2 Bugs / Feature Requests
 
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/powerman/perl-IO-Stream-Proxy-HTTPS/issues>.
+You will be notified automatically of any progress on your issue.
 
-=head1 DEPENDENCIES
+=head2 Source Code
 
-L<IO::Stream>.
+This is open source software. The code repository is available for
+public review and contribution under the terms of the license.
+Feel free to fork the repository and submit pull requests.
 
+L<https://github.com/powerman/perl-IO-Stream-Proxy-HTTPS>
 
-=head1 INCOMPATIBILITIES
+    git clone https://github.com/powerman/perl-IO-Stream-Proxy-HTTPS.git
 
-None reported.
+=head2 Resources
 
+=over
 
-=head1 BUGS AND LIMITATIONS
+=item * MetaCPAN Search
 
-No bugs have been reported.
+L<https://metacpan.org/search?q=IO-Stream-Proxy-HTTPS>
 
-Please report any bugs or feature requests to author, or
-C<bug-io-stream-proxy-https@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/dist/IO-Stream-Proxy-HTTPS>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/IO-Stream-Proxy-HTTPS>
+
+=item * CPAN Testers Matrix
+
+L<http://matrix.cpantesters.org/?dist=IO-Stream-Proxy-HTTPS>
+
+=item * CPANTS: A CPAN Testing Service (Kwalitee)
+
+L<http://cpants.cpanauthors.org/dist/IO-Stream-Proxy-HTTPS>
+
+=back
 
 
 =head1 AUTHOR
 
-Alex Efros  C<< <powerman-asdf@ya.ru> >>
+Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2008, Alex Efros C<< <powerman-asdf@ya.ru> >>. All rights reserved.
+This software is Copyright (c) 2008 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+This is free software, licensed under:
+
+  The MIT (X11) License
 
 
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
+=cut
